#include <Arduino.h>
#include <button.h>


Button::Button( int pin )
	:
	_pin( pin ),
	_last_state( digitalRead( pin )? true : false ),
	_last_millis( millis() )
{
}


void Button::add_event_at( int duration, int event_id )
{
	_press_events[ duration ] = event_id;
}


int Button::update()
{
	// reset event
	_event_id = 0;

	// get time
	int millis = ::millis();

	// get state and check for change
	bool state = digitalRead( _pin )? true : false;
	if( state != _last_state )
	{
		// if the button has become unpressed
		if( !state )
		{
			// check through events to see if it had been pressed long enough
			// to trigger one
			int duration = millis - _last_millis;
			for( std::map< int, int >::iterator i = _press_events.begin();
				 i != _press_events.end(); i++ )
			{
				if( duration > i->first )
					_event_id = i->second;
				else
					break;
			}
		}

		// update last state
		_last_state = state;
		_last_millis = millis;
	}

	return _event_id;
}


int Button::get_triggered_event()
{
	return _event_id;
}
