#include <map>

class Button
{
public:

	/**
	 * Constructor.
	 *
	 * @param pin the pin to monitor
	 */
	Button( int pin );

	/**
	 * Add a duration at which the specified event id should be triggered.
	 *
	 * @oaram duration the time at which the event should be triggered
	 * @param event_id a unique identifier for the event (not 0)
	 */
	void add_event_at( int duration, int event_id );

	/**
	 * Update internal state
	 */
	int update();

	/**
	 * Retrieve the event id of the event that was triggered at the last
	 * update, if there was one.
	 *
	 * @return event id, or 0
	 */
	int get_triggered_event();

protected:

	/** pin */
	int _pin;

	/** last state */
	bool _last_state;

	/** milliseconds since last state change */
	int _last_millis;

	/** triggered event */
	int _event_id;

	/** press events durations -> event ids */
	std::map< int, int > _press_events;

};
