#include "time.h"
#include <DS1307.h>
#include <Wire.h>


Time &Time::get_instance()
{
	static Time time;
	return time;
}


int Time::get_hours()
{
	return _hours;
}


int Time::get_minutes()
{
	return _minutes;
}


int Time::get_seconds()
{
	return _seconds;
}


void Time::update()
{
	// how many milliseonds have elapsed since we last checked?
	unsigned long millis = ::millis();
	unsigned long delta = millis - _last_millis + _carry;

	// update the previous time and carried-over milliseconds
	_last_millis = millis;
	_carry = delta % 1000;

	// add the seconds that have passed to the time
	_seconds += delta / 1000;
	while( _seconds >= 60 ) {
		_seconds -= 60;
		_minutes++;
		if( _minutes >= 60 ) {
			_minutes -= 60;
			_hours++;
			if( _hours >= 24 )
				_hours -= 24;
		}
	}
}


Time::Time()
	:
	_last_millis( millis() ),
	_carry( 0 )
{
	// get the time from the real-time clock
	int rtc_data[ 7 ];
	RTC.get( rtc_data, true );
	_hours = rtc_data[ DS1307_HR ];
	_minutes = rtc_data[ DS1307_MIN ];
	_seconds = rtc_data[ DS1307_SEC ];
}

